@@ -1,6 +1,16 @@
 import typing
 from .base_category import BaseCategory
-from vkbottle_types.responses import base, board
+from vkbottle_types.responses.board import (
+    AddTopicResponse,
+    CreateCommentResponse,
+    GetCommentsExtendedResponse,
+    GetCommentsResponse,
+    GetCommentsResponseModel,
+    GetTopicsExtendedResponse,
+    GetTopicsResponse,
+    GetTopicsResponseModel
+)
+from vkbottle_types.responses.base import OkResponse
 
 
 class BoardCategory(BaseCategory):
@@ -23,7 +33,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.addTopic", params)
-        model = board.AddTopicResponse
+        model = AddTopicResponse
         return model(**response).response
 
     async def close_topic(
@@ -36,7 +46,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.closeTopic", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def create_comment(
@@ -62,7 +72,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.createComment", params)
-        model = board.CreateCommentResponse
+        model = CreateCommentResponse
         return model(**response).response
 
     async def delete_comment(
@@ -76,7 +86,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.deleteComment", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def delete_topic(
@@ -89,7 +99,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.deleteTopic", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def edit_comment(
@@ -111,7 +121,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.editComment", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def edit_topic(
@@ -125,7 +135,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.editTopic", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def fix_topic(
@@ -138,7 +148,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.fixTopic", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def get_comments(
@@ -152,7 +162,7 @@ class BoardCategory(BaseCategory):
         extended: typing.Optional[bool] = None,
         sort: typing.Optional[str] = None,
         **kwargs
-    ) -> board.GetCommentsResponseModel:
+    ) -> GetCommentsResponseModel:
         """Returns a list of comments on a topic on a community's discussion board.
         :param group_id: ID of the community that owns the discussion board.
         :param topic_id: Topic ID.
@@ -167,8 +177,8 @@ class BoardCategory(BaseCategory):
         params = self.get_set_params(locals())
         response = await self.api.request("board.getComments", params)
         model = self.get_model(
-            {("extended",): board.GetCommentsExtendedResponse},
-            default=board.GetCommentsResponse,
+            {("extended",): GetCommentsExtendedResponse},
+            default=GetCommentsResponse,
             params=params,
         )
         return model(**response).response
@@ -184,7 +194,7 @@ class BoardCategory(BaseCategory):
         preview: typing.Optional[int] = None,
         preview_length: typing.Optional[int] = None,
         **kwargs
-    ) -> board.GetTopicsResponseModel:
+    ) -> GetTopicsResponseModel:
         """Returns a list of topics on a community's discussion board.
         :param group_id: ID of the community that owns the discussion board.
         :param topic_ids: IDs of topics to be returned (100 maximum). By default, all topics are returned. If this parameter is set, the 'order', 'offset', and 'count' parameters are ignored.
@@ -199,8 +209,8 @@ class BoardCategory(BaseCategory):
         params = self.get_set_params(locals())
         response = await self.api.request("board.getTopics", params)
         model = self.get_model(
-            {("extended",): board.GetTopicsExtendedResponse},
-            default=board.GetTopicsResponse,
+            {("extended",): GetTopicsExtendedResponse},
+            default=GetTopicsResponse,
             params=params,
         )
         return model(**response).response
@@ -215,7 +225,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.openTopic", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def restore_comment(
@@ -229,7 +239,7 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.restoreComment", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def unfix_topic(
@@ -242,5 +252,5 @@ class BoardCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("board.unfixTopic", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
