@@ -1,6 +1,6 @@
 import typing
 from .base_category import BaseCategory
-from vkbottle_types.responses import gifts
+from vkbottle_types.responses.gifts import GetResponse, GetResponseModel
 
 
 class GiftsCategory(BaseCategory):
@@ -10,7 +10,7 @@ class GiftsCategory(BaseCategory):
         count: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         **kwargs
-    ) -> gifts.GetResponseModel:
+    ) -> GetResponseModel:
         """Returns a list of user gifts.
         :param user_id: User ID.
         :param count: Number of gifts to return.
@@ -19,5 +19,5 @@ class GiftsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("gifts.get", params)
-        model = gifts.GetResponse
+        model = GetResponse
         return model(**response).response
