@@ -12,34 +12,31 @@ from vkbottle_types.objects import (
 
 
 class CheckLinkResponse(BaseResponse):
-    response: typing.Optional["CheckLinkResponseModel"] = None
+    response: UtilsLinkChecked = None
 
 
 class GetLastShortenedLinksResponse(BaseResponse):
-    response: typing.Optional["GetLastShortenedLinksResponseModel"] = None
+    response: "GetLastShortenedLinksResponseModel" = None
 
 
 class GetLinkStatsExtendedResponse(BaseResponse):
-    response: typing.Optional["GetLinkStatsExtendedResponseModel"] = None
+    response: UtilsLinkStatsExtended = None
 
 
 class GetLinkStatsResponse(BaseResponse):
-    response: typing.Optional["GetLinkStatsResponseModel"] = None
+    response: UtilsLinkStats = None
 
 
 class GetServerTimeResponse(BaseResponse):
-    response: typing.Optional["GetServerTimeResponseModel"] = None
+    response: int = None
 
 
 class GetShortLinkResponse(BaseResponse):
-    response: typing.Optional["GetShortLinkResponseModel"] = None
+    response: UtilsShortLink = None
 
 
 class ResolveScreenNameResponse(BaseResponse):
-    response: typing.Optional["ResolveScreenNameResponseModel"] = None
-
-
-CheckLinkResponseModel = UtilsLinkChecked
+    response: UtilsDomainResolved = None
 
 
 class GetLastShortenedLinksResponseModel(BaseResponse):
@@ -47,21 +44,6 @@ class GetLastShortenedLinksResponseModel(BaseResponse):
     items: typing.Optional[typing.List["UtilsLastShortenedLink"]] = None
 
 
-GetLinkStatsExtendedResponseModel = UtilsLinkStatsExtended
-
-
-GetLinkStatsResponseModel = UtilsLinkStats
-
-
-GetServerTimeResponseModel = int
-
-
-GetShortLinkResponseModel = UtilsShortLink
-
-
-ResolveScreenNameResponseModel = UtilsDomainResolved
-
-
 for item in locals().copy().values():
     if inspect.isclass(item) and issubclass(item, BaseResponse):
         item.update_forward_refs()
